spannertools.OctavationSpanner
==============================

.. abjad-lineage:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner

.. autoclass:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.adjust_automatically
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.append
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.append_left
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.attach
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.components
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.detach
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.extend
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.extend_left
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.fracture
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.fuse
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.get_duration
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.get_timespan
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.index
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.leaves
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.override
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.pop
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.pop_left
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.set
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.start
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.stop
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__call__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__contains__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__copy__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__eq__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__getitem__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__len__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__lt__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__ne__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.set
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.start
   :noindex:

.. autoattribute:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.stop
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.adjust_automatically
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.attach
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner.__repr__
   :noindex:
